{
  "version_mapping": {
    "1.8": [
      [
        "==",
        "1.8.*"
      ]
    ],
    "1.8.0.1": [
      [
        "==",
        "1.8.*"
      ]
    ],
    "1.8.0.2": [
      [
        "==",
        "1.8.*"
      ]
    ],
    "1.8.0.3": [
      [
        "==",
        "1.8.*"
      ]
    ],
    "1.8.1": [
      [
        "==",
        "1.8.*"
      ]
    ],
    "1.8.1.1": [
      [
        "==",
        "1.8.*"
      ]
    ],
    "1.8.1.2": [
      [
        "==",
        "1.8.*"
      ]
    ],
    "1.8.2": [
      [
        "==",
        "1.8.0.2"
      ]
    ],
    "1.8.2.1": [
      [
        "==",
        "1.8.*"
      ]
    ],
    "1.9": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.0.2": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.0.3": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.0.4": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.0.5": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.1": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.1.1": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.1.2": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.2": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.3": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.4": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.4.1": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.4.2": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.4.3": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.4.4": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.9.4.5": [
      [
        ">=",
        "1.9.0.2"
      ],
      [
        "<",
        "1.10"
      ]
    ],
    "1.10": [
      [
        ">=",
        "1.10"
      ],
      [
        "<",
        "1.11"
      ]
    ],
    "1.10.0.1": [
      [
        ">=",
        "1.10"
      ],
      [
        "<",
        "1.11"
      ]
    ],
    "1.10.0.2": [
      [
        ">=",
        "1.10"
      ],
      [
        "<",
        "1.11"
      ]
    ],
    "1.10.0.3": [
      [
        ">=",
        "1.10"
      ],
      [
        "<",
        "1.11"
      ]
    ],
    "1.10.0.4": [
      [
        ">=",
        "1.10"
      ],
      [
        "<",
        "1.11"
      ]
    ],
    "1.10.0.5": [
      [
        ">=",
        "1.10"
      ],
      [
        "<",
        "1.11"
      ]
    ],
    "1.10.1": [
      [
        ">=",
        "1.10"
      ],
      [
        "<",
        "1.11"
      ]
    ],
    "1.11": [
      [
        ">=",
        "1.10"
      ],
      [
        "<",
        "1.11"
      ]
    ],
    "1.11.1": [
      [
        ">=",
        "1.10"
      ],
      [
        "<",
        "1.11"
      ]
    ],
    "1.12": [
      [
        ">=",
        "1.12"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.12.0.1": [
      [
        ">=",
        "1.12.1"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.12.0.2": [
      [
        ">=",
        "1.12.1"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.12.1": [
      [
        ">=",
        "1.12.3"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.12.2": [
      [
        ">=",
        "1.12.3"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.12.2.1": [
      [
        ">=",
        "1.12.3"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.12.3": [
      [
        ">=",
        "1.12.3"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.12.3.1": [
      [
        ">=",
        "1.12.3"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.12.3.2": [
      [
        ">=",
        "1.12.3"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.12.3.3": [
      [
        ">=",
        "1.12.3"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.12.4": [
      [
        ">=",
        "1.12.3.3"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.12.4.2": [
      [
        ">=",
        "1.12.3.3"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.13": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.13.0.1": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.13.1": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.13.2": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.13.2.1": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.14": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.14.0.1": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.14.0.2": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.14.0.3": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.14.0.4": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.14.1": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.15": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.15.0.1": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.15.0.2": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.15.0.3": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.15.0.4": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.15.0.5": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.15.0.6": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.15.1": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.15.1.1": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.15.2": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.15.2.1": [
      [
        ">=",
        "1.12.4"
      ],
      [
        "<",
        "1.13"
      ]
    ],
    "1.16": [
      [
        ">=",
        "1.16"
      ],
      [
        "<",
        "1.17"
      ]
    ],
    "1.16.0.1": [
      [
        ">=",
        "1.16"
      ],
      [
        "<",
        "1.17"
      ]
    ],
    "1.16.0.2": [
      [
        ">=",
        "1.16"
      ],
      [
        "<",
        "1.17"
      ]
    ],
    "1.17": [
      [
        ">=",
        "1.16"
      ],
      [
        "<",
        "1.17"
      ]
    ],
    "1.17.0.1": [
      [
        ">=",
        "1.16"
      ],
      [
        "<",
        "1.17"
      ]
    ],
    "1.17.0.2": [
      [
        ">=",
        "1.16"
      ],
      [
        "<",
        "1.17"
      ]
    ],
    "1.17.0.3": [
      [
        ">=",
        "1.16"
      ],
      [
        "<",
        "1.17"
      ]
    ],
    "1.17.1": [
      [
        ">=",
        "1.16"
      ],
      [
        "<",
        "1.17"
      ]
    ],
    "1.17.2": [
      [
        ">=",
        "1.16"
      ],
      [
        "<",
        "1.17"
      ]
    ],
    "1.18": [
      [
        ">=",
        "1.17"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "1.19": [
      [
        ">=",
        "1.17"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "1.19.1": [
      [
        ">=",
        "1.17"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "1.19.2": [
      [
        ">=",
        "1.17"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "1.19.2.1": [
      [
        ">=",
        "1.17"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "1.19.2.2": [
      [
        ">=",
        "1.17"
      ],
      [
        "<",
        "1.17.1"
      ]
    ],
    "1.19.2.3": [
      [
        ">=",
        "1.17"
      ],
      [
        "<",
        "1.17.1"
      ]
    ],
    "1.19.2.4": [
      [
        ">=",
        "1.17"
      ],
      [
        "<",
        "1.17.1"
      ]
    ],
    "2.0": [
      [
        ">=",
        "1.17.2"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.0.0.1": [
      [
        ">=",
        "1.17.2"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.0.1": [
      [
        ">=",
        "1.17.2"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.0.1.1": [
      [
        ">=",
        "1.17.2"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.0.2": [
      [
        ">=",
        "1.17.3"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.0.3": [
      [
        ">=",
        "1.17.3"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.0.4": [
      [
        ">=",
        "1.17.3"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.0.5": [
      [
        ">=",
        "1.17.3"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.0.6": [
      [
        ">=",
        "1.17.3"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.1": [
      [
        ">=",
        "1.17.3"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.1.1": [
      [
        ">=",
        "1.17.3"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.1.2": [
      [
        ">=",
        "1.17.3"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.1.3": [
      [
        ">=",
        "1.17.4.2"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.2": [
      [
        ">=",
        "1.17.4.2"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.2.1": [
      [
        ">=",
        "1.17.4.2"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.2.2": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.2.2.1": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.2.3": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.2.3.1": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.2.3.2": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.3": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.3.1": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.4": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.5": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.6": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.7": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.7.1": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.7.2": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.7.3": [
      [
        ">=",
        "1.17.5"
      ],
      [
        "<",
        "1.18"
      ]
    ],
    "2.8": [
      [
        ">=",
        "1.20"
      ],
      [
        "<",
        "1.21"
      ]
    ],
    "2.8.0.1": [
      [
        ">=",
        "1.20"
      ],
      [
        "<",
        "1.21"
      ]
    ],
    "2.8.1": [
      [
        ">=",
        "1.20"
      ],
      [
        "<",
        "1.21"
      ]
    ],
    "2.9": [
      [
        ">=",
        "1.20"
      ],
      [
        "<",
        "1.21"
      ]
    ],
    "2.9.1": [
      [
        ">=",
        "1.20"
      ],
      [
        "<",
        "1.21"
      ]
    ],
    "2.9.1.1": [
      [
        ">=",
        "1.20"
      ],
      [
        "<",
        "1.21"
      ]
    ],
    "2.9.2": [
      [
        ">=",
        "1.20"
      ],
      [
        "<",
        "1.21"
      ]
    ],
    "2.9.2.1": [
      [
        ">=",
        "1.20"
      ],
      [
        "<",
        "1.21"
      ]
    ]
  },
  "definitions": {
    "1.8": "data Pandoc = Pandoc Meta [Block]\ndata Meta\n  = Meta {docTitle :: [Inline],\n          docAuthors :: [[Inline]],\n          docDate :: [Inline]}\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\ntype Format = String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | EmDash\n  | EnDash\n  | Apostrophe\n  | Ellipses\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.8.0.2": "data Pandoc = Pandoc Meta [Block]\ndata Meta\n  = Meta {docTitle :: [Inline],\n          docAuthors :: [[Inline]],\n          docDate :: [Inline]}\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\ntype Format = String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | EmDash\n  | EnDash\n  | Apostrophe\n  | Ellipses\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.8.2": "data Pandoc = Pandoc Meta [Block]\ndata Meta\n  = Meta {docTitle :: [Inline],\n          docAuthors :: [[Inline]],\n          docDate :: [Inline]}\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\ntype Format = String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | EmDash\n  | EnDash\n  | Apostrophe\n  | Ellipses\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.9.0.1": "data Pandoc = Pandoc Meta [Block]\ndata Meta\n  = Meta {docTitle :: [Inline],\n          docAuthors :: [[Inline]],\n          docDate :: [Inline]}\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\ntype Format = String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.9.0.2": "data Pandoc = Pandoc Meta [Block]\ndata Meta\n  = Meta {docTitle :: [Inline],\n          docAuthors :: [[Inline]],\n          docDate :: [Inline]}\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\ntype Format = String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.9.1": "data Pandoc = Pandoc Meta [Block]\ndata Meta\n  = Meta {docTitle :: [Inline],\n          docAuthors :: [[Inline]],\n          docDate :: [Inline]}\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\ntype Format = String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.1.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.1.2": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.2": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.2.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.2.2": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.2.3": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.3": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.3.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.3.2": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.3.3": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.4": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.4.3": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.4.4": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.12.4.5": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link [Inline] Target\n  | Image [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.16": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.16.0.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\n",
    "1.16.1.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.0.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.0.2": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.0.3": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.0.4": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.0.5": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.2": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.3": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.3.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.4": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.4.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.4.2": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.5": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.5.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.5.2": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.5.3": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.5.4": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.19": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.6": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.17.6.1": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map String MetaValue}\ndata MetaValue\n  = MetaMap (Map String MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString String\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: String -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (String, [String], [(String, String)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format String\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr String\n  | RawBlock Format String\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (String, String)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str String\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr String\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType String\n  | RawInline Format String\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: String,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n",
    "1.20": "data Pandoc = Pandoc Meta [Block]\nnewtype Meta = Meta {unMeta :: Map Text MetaValue}\ndata MetaValue\n  = MetaMap (Map Text MetaValue)\n  | MetaList [MetaValue]\n  | MetaBool Bool\n  | MetaString Text\n  | MetaInlines [Inline]\n  | MetaBlocks [Block]\nnullMeta :: Meta\nisNullMeta :: Meta -> Bool\nlookupMeta :: Text -> Meta -> Maybe MetaValue\ndocTitle :: Meta -> [Inline]\ndocAuthors :: Meta -> [[Inline]]\ndocDate :: Meta -> [Inline]\ndata Alignment\n  = AlignLeft | AlignRight | AlignCenter | AlignDefault\ntype ListAttributes = (Int, ListNumberStyle, ListNumberDelim)\ndata ListNumberStyle\n  = DefaultStyle\n  | Example\n  | Decimal\n  | LowerRoman\n  | UpperRoman\n  | LowerAlpha\n  | UpperAlpha\ndata ListNumberDelim = DefaultDelim | Period | OneParen | TwoParens\ntype Attr = (Text, [Text], [(Text, Text)])\nnullAttr :: Attr\ntype TableCell = [Block]\nnewtype Format = Format Text\ndata Block\n  = Plain [Inline]\n  | Para [Inline]\n  | LineBlock [[Inline]]\n  | CodeBlock Attr Text\n  | RawBlock Format Text\n  | BlockQuote [Block]\n  | OrderedList ListAttributes [[Block]]\n  | BulletList [[Block]]\n  | DefinitionList [([Inline], [[Block]])]\n  | Header Int Attr [Inline]\n  | HorizontalRule\n  | Table [Inline] [Alignment] [Double] [TableCell] [[TableCell]]\n  | Div Attr [Block]\n  | Null\ndata QuoteType = SingleQuote | DoubleQuote\ntype Target = (Text, Text)\ndata MathType = DisplayMath | InlineMath\ndata Inline\n  = Str Text\n  | Emph [Inline]\n  | Strong [Inline]\n  | Strikeout [Inline]\n  | Superscript [Inline]\n  | Subscript [Inline]\n  | SmallCaps [Inline]\n  | Quoted QuoteType [Inline]\n  | Cite [Citation] [Inline]\n  | Code Attr Text\n  | Space\n  | SoftBreak\n  | LineBreak\n  | Math MathType Text\n  | RawInline Format Text\n  | Link Attr [Inline] Target\n  | Image Attr [Inline] Target\n  | Note [Block]\n  | Span Attr [Inline]\ndata Citation\n  = Citation {citationId :: Text,\n              citationPrefix :: [Inline],\n              citationSuffix :: [Inline],\n              citationMode :: CitationMode,\n              citationNoteNum :: Int,\n              citationHash :: Int}\ndata CitationMode = AuthorInText | SuppressAuthor | NormalCitation\npandocTypesVersion :: Version\n"
  }
}