# coding: utf-8

name = "pandoc"
version = "2.0a4"
license = "MIT License"
description = "Pandoc Documents for Python"
author = "Sébastien Boisgérault"
author_email = "Sebastien.Boisgerault@mines-paristech.fr"
classifiers = [
    "Programming Language :: Python :: 3",
    "Development Status :: 3 - Alpha",
    "Topic :: Software Development",
    "Topic :: Text Editors :: Text Processing",
]
